
module cordic_core (
	clock,			// clock
	xreset,			// reset (low active)
	End,			// Input  value of End
	alpha_in,		// Input  value of alpha
	delta_in,		// Input  value of delta
	x_in, 			// Input  value of x
	y_in, 			// Input  value of y
	z_in, 			// Input  value of z
	x_out, 			// Output value of x
	y_out, 			// Output value of y
	z_out			// Output value of z
);

	//Inputs
	input						clock;
	input						xreset;
	input						End;
	input		signed	[15:0]	x_in;
   	input   	signed	[15:0]	y_in;
   	input		signed	[15:0]	z_in;
   	input		signed	[15:0]	alpha_in;
   	input   	signed	[15:0]	delta_in;

	//Outputs
   	output		signed	[15:0]	x_out;
   	output		signed	[15:0]	y_out;
   	output		signed	[15:0]	z_out;

	//Regs
	reg			signed	[15:0]	x_out;
	reg			signed	[15:0]	y_out;
	reg			signed	[15:0]	z_out;

	//Wires(31bits. because of signed and multiply)
	wire 		signed	[31:0]	x_temp;
	wire 		signed	[31:0]	y_temp;

	//multiply delta*x
	assign x_temp = delta_in * x_in;

	//multiply delta*y
	assign y_temp = delta_in * y_in;


	always @ (posedge clock or negedge xreset) begin
		if (xreset == 0) begin
			x_out <= 0;
		end 
		else begin
			if(End) begin
				x_out <= x_out;
			end
			else begin
				x_out <= x_in - y_temp[29:14];
			end
		end
	end

	always @ (posedge clock or negedge xreset) begin
		if (xreset == 0) begin
			y_out <= 0;
		end 
		else begin
			if(End) begin
				y_out <= y_out;
			end
			else begin
				y_out <= y_in + x_temp[29:14];
			end
		end
	end


	always @ (posedge clock or negedge xreset) begin
		if (xreset == 0) begin
			z_out <= 0;
		end 
		else begin
			if(End) begin
				z_out <= z_out;
			end
			else begin
				z_out <= z_in + alpha_in;
			end
		end
	end


endmodule
