
module cordic_data(
	clock,			// Input system clock
	reset,			// Input system reset
	End,			// Input system End
	theta_in,		// Input value of theta
	x_init,			// Initial value of x
	y_init,        	// Initial value of y
	z_init,        	// Initial value of z
	select,			// Input value of select
	address,		// Input value of address
	x_out,			// Output value of x
	y_out,			// Output value of y
	z_out 			// Output value of z
);

	input		signed	[15:0]	x_init;
   	input   	signed	[15:0]	y_init;
   	input   	signed	[15:0]	z_init;
   	input   	signed	[15:0]	theta_in;
	input				[3:0]	address;
	input						clock;
	input						reset;
	input						select;
	input						End;

	output		signed	[15:0]	x_out;	
	output		signed	[15:0]	y_out;	
	output		signed	[15:0]	z_out;	

	wire		signed	[15:0]	X1;
	wire		signed	[15:0]	Y1;
	wire		signed	[15:0]	Z1;

	wire		signed	[15:0]	DELTA1;
	wire		signed	[15:0]	ALPHA1;
	wire		signed	[15:0]	DELTA2;
	wire		signed	[15:0]	ALPHA2;

	wire		signed	[15:0]	X_FB;
	wire		signed	[15:0]	Y_FB;
	wire		signed	[15:0]	Z_FB;

	assign		x_out = X_FB;
	assign		y_out = Y_FB;
	assign		z_out = Z_FB;

codric_init_SLT u_codric_init_SLT(
	.select			(	select		),		// Select as output value from X_init or X_in
	.x_init			(	x_init		),		// Initial value of x
	.y_init			(	y_init		),		// Initial value of y
	.z_init			(	z_init		),		// Initial value of z
	.x_in			(	X_FB		),		// Itarated value of x
	.y_in			(	Y_FB		),		// Itarated value of y
	.z_in			(	Z_FB		),		// Itarated value of z
	.x_out			(	X1			),		// Selected value of x
	.y_out			(	Y1			),		// Selected value of y
	.z_out			(	Z1			) 		// Selected value of z
);

codric_rom u_codric_rom(
	.clock			(	clock		),		// clock input
	.address		(	address		),		// ROM address (0 to 15) : depneds on CORDIC iteration
	.alpha_out		(	ALPHA1		),		// Alpha value : arctan(2^(-i))
	.delta_out		(	DELTA1		)		// Delta value : 2^(-i)
);  

cordic_check u_cordic_check(
	.alpha_in		(	ALPHA1		), 		// Input  value of delta
	.delta_in		(	DELTA1		), 		// Input  value of alpha
	.theta_in		(	theta_in	), 		// Input  value of theta
	.z_in			(	Z1			),     	// Input  value of z
	.alpha_out		(	ALPHA2		),		// Output value of delta
	.delta_out		(	DELTA2		)		// Output value of alpha
);       


cordic_core u_cordic_core(
	.clock			(	clock	),		// clock
	.xreset			(	reset	),		// reset (low active)
	.End			(	End		),		// Input  value of End
	.alpha_in		(	ALPHA2	),			// Input  value of delta
	.delta_in		(	DELTA2	),			// Input  value of alpha
	.x_in			(	X1		), 	// Input  value of x
	.y_in			(	Y1		), 	// Input  value of y
	.z_in			(	Z1		), 	// Input  value of z
	.x_out			(	X_FB	), 		// Output value of x
	.y_out			(	Y_FB	), 		// Output value of y
	.z_out			(	Z_FB	)		// Output value of z
);

endmodule